@@ -100,8 +100,9 @@ struct FMTreeModelDetails
     guint monitoring_update_idle_id;
 
     gboolean show_hidden_files;
+    gboolean show_backup_files;
     gboolean show_only_directories;
-
+	
     GList *highlighted_files;
 };
 
@@ -778,9 +779,13 @@ stop_monitoring_directory (FMTreeModel *model, TreeNode *node)
 static void
 destroy_children_without_reporting (FMTreeModel *model, TreeNode *parent)
 {
-    while (parent->first_child != NULL)
+    TreeNode *current_child = parent->first_child;
+    TreeNode *next_child;
+    while (current_child != NULL)
     {
-        destroy_node_without_reporting (model, parent->first_child);
+        next_child = current_child->next;
+        destroy_node_without_reporting (model, current_child);
+        current_child = next_child;
     }
 }
 
@@ -956,7 +961,8 @@ should_show_file (FMTreeModel *model, CajaFile *file)
 
     should = caja_file_should_show (file,
                                     model->details->show_hidden_files,
-                                    TRUE);
+                                    TRUE,
+				    model->details->show_backup_files);
 
     if (should
             && model->details->show_only_directories
